@@ -60,6 +60,7 @@ import java.util.Map;
 import java.util.Set;
 import org.json.JSONArray;
 import com.openexchange.ajax.AJAXServlet;
+import com.openexchange.ajax.fields.OrderFields;
 import com.openexchange.ajax.requesthandler.AJAXRequestData;
 import com.openexchange.ajax.requesthandler.AJAXRequestResult;
 import com.openexchange.api2.ContactInterfaceFactory;
@@ -68,6 +69,7 @@ import com.openexchange.groupware.AbstractOXException;
 import com.openexchange.groupware.contact.ContactInterface;
 import com.openexchange.groupware.container.Contact;
 import com.openexchange.groupware.ldap.User;
+import com.openexchange.groupware.search.Order;
 import com.openexchange.tools.iterator.SearchIterator;
 import com.openexchange.tools.servlet.AjaxException;
 import com.openexchange.tools.session.ServerSession;
@@ -117,7 +119,7 @@ public final class AllAction extends AbstractUserAction {
              */
             final int[] columns = parseIntArrayParameter(AJAXServlet.PARAMETER_COLUMNS, request);
             final int orderBy = parseIntParameter(AJAXServlet.PARAMETER_SORT, request);
-            final String orderDirection = request.getParameter(AJAXServlet.PARAMETER_ORDER);
+            final Order order = OrderFields.parse(request.getParameter(AJAXServlet.PARAMETER_ORDER));
 
             final int leftHandLimit = parseIntParameter(AJAXServlet.LEFT_HAND_LIMIT, request);
             final int rightHandLimit = parseIntParameter(AJAXServlet.RIGHT_HAND_LIMIT, request);
@@ -165,7 +167,7 @@ public final class AllAction extends AbstractUserAction {
                                 lhl,
                                 50000,
                                 orderBy,
-                                orderDirection,
+                                order,
                                 checkedCols);
                     } else {
                         it =
@@ -174,7 +176,7 @@ public final class AllAction extends AbstractUserAction {
                                 lhl,
                                 rightHandLimit,
                                 orderBy,
-                                orderDirection,
+                                order,
                                 checkedCols);
                     }
                     try {
@@ -213,7 +215,7 @@ public final class AllAction extends AbstractUserAction {
                     Collections.sort(allUsers, Comparators.getComparator(
                         orderField,
                         session.getUser().getLocale(),
-                        "desc".equalsIgnoreCase(orderDirection)));
+                        Order.DESCENDING.equals(order)));
                     final int lhl = leftHandLimit < 0 ? 0 : leftHandLimit;
                     int rhl = rightHandLimit <= 0 ? 50000 : rightHandLimit;
                     if (rhl - lhl >= allUsers.size()) {
