@@ -28,7 +28,7 @@
  *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
  *    given Attribution for the derivative code and a license granting use.
  *
- *     Copyright (C) 2004-2006 Open-Xchange, Inc.
+ *     Copyright (C) 2004-2010 Open-Xchange, Inc.
  *     Mail: info@open-xchange.com
  *
  *
@@ -152,6 +152,10 @@ public final class UserParser {
                 contact.setObjectID(parseInt(userJSONObject, UserField.ID.getName()));
             }
 
+            if (userJSONObject.has(UserField.INTERNAL_USERID.getName())) {
+                contact.setInternalUserId(parseInt(userJSONObject, UserField.INTERNAL_USERID.getName()));
+            }
+
             if (userJSONObject.has(UserField.CREATED_BY.getName())) {
                 contact.setCreatedBy(parseInt(userJSONObject, UserField.CREATED_BY.getName()));
             }
